searchData={"items":[{"type":"module","title":"Ollama","doc":"![Ollama-ex](https://raw.githubusercontent.com/lebrunel/ollama-ex/main/media/poster.webp)\n\n![License](https://img.shields.io/github/license/lebrunel/ollama-ex?color=informational)\n\n[Ollama](https://ollama.ai) is a nifty little tool for running large language\nmodels locally, and this is a nifty little library for working with Ollama in\nElixir.","ref":"Ollama.html"},{"type":"module","title":"Highlights - Ollama","doc":"- API client fully implementing the Ollama API - see `Ollama.API`.\n- Stream API responses to any Elixir process.\n- OpenAI API to Ollama API proxy plug - *COMING SOON*","ref":"Ollama.html#module-highlights"},{"type":"module","title":"Installation - Ollama","doc":"The package can be installed by adding `ollama` to your list of dependencies\nin `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:ollama, \"0.3.0\"}\n  ]\nend\n```","ref":"Ollama.html#module-installation"},{"type":"module","title":"Quickstart - Ollama","doc":"For more examples, refer to the `Ollama.API` documentation.\n\n#","ref":"Ollama.html#module-quickstart"},{"type":"module","title":"1. Generate a completion - Ollama","doc":"```elixir\niex> api = Ollama.API.new\n\niex> Ollama.API.completion(api, [\n...>   model: \"llama2\",\n...>   prompt: \"Why is the sky blue?\",\n...> ])\n{:ok, %{\"response\" => \"The sky is blue because it is the color of the sky.\", ...}}\n```\n\n#","ref":"Ollama.html#module-1-generate-a-completion"},{"type":"module","title":"2. Generate the next message in a chat - Ollama","doc":"```elixir\niex> api = Ollama.API.new\niex> messages = [\n...>   %{role: \"system\", content: \"You are a helpful assistant.\"},\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Ollama.API.chat(api, [\n...>   model: \"llama2\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"message\" => %{\n  \"role\" => \"assistant\",\n  \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}, ...}}\n```\n\n#","ref":"Ollama.html#module-2-generate-the-next-message-in-a-chat"},{"type":"module","title":"3. Stream response to any Elixir process - Ollama","doc":"Both the completion and chat endpoints support streaming. Passing the `:stream`\noptions as `true` will return a `t:Task.t/0` that streams messages back to the\ncalling process. Alteratively, passing a `t:pid/0` will stream messages to that\nprocess.\n\n```elixir\niex> Ollama.API.completion(api, [\n...>   model: \"llama2\",\n...>   prompt: \"Why is the sky blue?\",\n...>   stream: true,\n...> ])\n{:ok, %Task{pid: current_message_pid}}\n\niex> Ollama.API.chat(api, [\n...>   model: \"llama2\",\n...>   messages: messages,\n...>   stream: true,\n...> ])\n{:ok, %Task{pid: current_message_pid}}\n```\n\nYou could manually create a `receive` block to handle messages.\n\n```elixir\niex> receive do\n...>   {^current_message_pid, {:data, %{\"done\" => true} = data}} ->\n...>     # handle last message\n...>   {^current_message_pid, {:data, data}} ->\n...>     # handle message\n...>   {_pid, _data_} ->\n...>     # this message was not expected!\n...>  end\n```\n\nIn most cases you will probably use `c:GenServer.handle_info/2`. See the\n[section on Streaming](`m:Ollama.API#module-streaming`) for more examples.","ref":"Ollama.html#module-3-stream-response-to-any-elixir-process"},{"type":"module","title":"Ollama.API","doc":"Client module for interacting with the Ollama API.\n\nCurrently supporting all Ollama API endpoints except pushing models (`/api/push`),\nwhich is coming soon.","ref":"Ollama.API.html"},{"type":"module","title":"Usage - Ollama.API","doc":"Assuming you have Ollama running on localhost, and that you have installed a\nmodel, use `completion/2` or `chat/2` interract with the model.\n\n    iex> api = Ollama.API.new\n\n    iex> Ollama.API.completion(api, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Why is the sky blue?\",\n    ...> ])\n    {:ok, %{\"response\" => \"The sky is blue because it is the color of the sky.\", ...}}\n\n    iex> Ollama.API.chat(api, [\n    ...>   model: \"llama2\",\n    ...>   messages: [\n    ...>     %{role: \"system\", content: \"You are a helpful assistant.\"},\n    ...>     %{role: \"user\", content: \"Why is the sky blue?\"},\n    ...>     %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n    ...>     %{role: \"user\", content: \"How is that different than mie scattering?\"},\n    ...>   ],\n    ...> ])\n    {:ok, %{\"message\" => %{\n      \"role\" => \"assistant\",\n      \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n    }, ...}}","ref":"Ollama.API.html#module-usage"},{"type":"module","title":"Streaming - Ollama.API","doc":"By default, all enpoints are called with streaming disabled, blocking until\nthe HTTP request completes and the response body is returned. For endpoints\nwhere streaming is supported, the `:stream` option can be set to `true` or a\n`t:pid/0`. When streaming is enabled, the function returns a `t:Task.t/0`,\nwhich asynchronously sends messages back to either the calling process, or the\nprocess associated with the given `t:pid/0`.\n\nMessages will be sent in the following format, allowing the recieving process\nto pattern match against the pid of the async task if known:\n\n    {request_pid, {:data, data}}\n\nThe data is a map from the Ollama JSON message. See\n[Ollama API docs](https://github.com/ollama/ollama/blob/main/docs/api.md).\n\nThe following example show's how a LiveView process may by constructed to both\ncreate the streaming request and recieve the streaming messages.\n\n    defmodule Ollama.ChatLive do\n      use Phoenix.LiveView\n\n      # When the client invokes the \"prompt\" event, create a streaming request\n      # and optionally store the request task into the assigns\n      def handle_event(\"prompt\", %{\"message\" => prompt}, socket) do\n        api = Ollama.API.new()\n        {:ok, task} = Ollama.API.completion(api, [\n          model: \"llama2\",\n          prompt: prompt,\n          stream: true,\n        ])\n\n        {:noreply, assign(socket, current_request: task)}\n      end\n\n      # The request task streams messages back to the LiveView process\n      def handle_info({_request_pid, {:data, _data}} = message, socket) do\n        pid = socket.assigns.current_request.pid\n        case message do\n          {^pid, {:data, %{\"done\" => false} = data}} ->\n            # handle each streaming chunk\n\n          {^pid, {:data, %{\"done\" => true} = data}} ->\n            # handle the final streaming chunk\n\n          {_pid, _data} ->\n            # this message was not expected!\n        end\n      end\n    end","ref":"Ollama.API.html#module-streaming"},{"type":"function","title":"Ollama.API.chat/2","doc":"Generates the next message in a chat using the specified model. Optionally\nstreamable.","ref":"Ollama.API.html#chat/2"},{"type":"function","title":"Options - Ollama.API.chat/2","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n* `:messages` (list of `t:map/0`) - Required. List of messages - used to keep a chat memory.\n* `:template` (`t:String.t/0`) - Prompt template, overriding the model default.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.API.html#chat/2-options"},{"type":"function","title":"Message structure - Ollama.API.chat/2","doc":"Each message is a map with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `system`, `user` or `assistant`.\n* `:content` (`t:String.t/0`) - Required. The content of the message.\n* `:images` (list of `t:String.t/0`) - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.API.html#chat/2-message-structure"},{"type":"function","title":"Examples - Ollama.API.chat/2","doc":"iex> messages = [\n    ...>   %{role: \"system\", content: \"You are a helpful assistant.\"},\n    ...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n    ...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n    ...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n    ...> ]\n\n    iex> Ollama.API.chat(api, [\n    ...>   model: \"llama2\",\n    ...>   messages: messages,\n    ...> ])\n    {:ok, %{\"message\" => %{\n      \"role\" => \"assistant\",\n      \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n    }, ...}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.API.chat(api, [\n    ...>   model: \"llama2\",\n    ...>   messages: messages,\n    ...>   stream: true,\n    ...> ])\n    {:ok, Task{}}","ref":"Ollama.API.html#chat/2-examples"},{"type":"function","title":"Ollama.API.check_blob/2","doc":"Checks a blob exists in ollama by its digest or binary data.","ref":"Ollama.API.html#check_blob/2"},{"type":"function","title":"Examples - Ollama.API.check_blob/2","doc":"iex> Ollama.API.check_blob(api, \"sha256:fe938a131f40e6f6d40083c9f0f430a515233eb2edaa6d72eb85c50d64f2300e\")\n    {:ok, true}\n\n    iex> Ollama.API.check_blob(api, \"this should not exist\")\n    {:ok, false}","ref":"Ollama.API.html#check_blob/2-examples"},{"type":"function","title":"Ollama.API.completion/2","doc":"Generates a completion for the given prompt using the specified model.\nOptionally streamable.","ref":"Ollama.API.html#completion/2"},{"type":"function","title":"Options - Ollama.API.completion/2","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n* `:prompt` (`t:String.t/0`) - Required. Prompt to generate a response for.\n* `:images` (list of `t:String.t/0`) - A list of Base64 encoded images to be included with the prompt (for multimodal models only).\n* `:system` (`t:String.t/0`) - System prompt, overriding the model default.\n* `:template` (`t:String.t/0`) - Prompt template, overriding the model default.\n* `:context` - The context parameter returned from a previous `f:completion/2` call (enabling short conversational memory).\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.API.html#completion/2-options"},{"type":"function","title":"Examples - Ollama.API.completion/2","doc":"iex> Ollama.API.completion(api, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Why is the sky blue?\",\n    ...> ])\n    {:ok, %{\"response\": \"The sky is blue because it is the color of the sky.\", ...}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.API.completion(api, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Why is the sky blue?\",\n    ...>   stream: true,\n    ...> ])\n    {:ok, %Task{}}","ref":"Ollama.API.html#completion/2-examples"},{"type":"function","title":"Ollama.API.copy_model/2","doc":"Creates a model with another name from an existing model.","ref":"Ollama.API.html#copy_model/2"},{"type":"function","title":"Options - Ollama.API.copy_model/2","doc":"* `:source` (`t:String.t/0`) - Required. Name of the model to copy from.\n* `:destination` (`t:String.t/0`) - Required. Name of the model to copy to.","ref":"Ollama.API.html#copy_model/2-options"},{"type":"function","title":"Example - Ollama.API.copy_model/2","doc":"iex> Ollama.API.copy_model(api, [\n    ...>   source: \"llama2\",\n    ...>   destination: \"llama2-backup\"\n    ...> ])\n    {:ok, true}","ref":"Ollama.API.html#copy_model/2-example"},{"type":"function","title":"Ollama.API.create_blob/2","doc":"Creates a blob from its binary data.","ref":"Ollama.API.html#create_blob/2"},{"type":"function","title":"Example - Ollama.API.create_blob/2","doc":"iex> Ollama.API.create_blob(api, data)\n    {:ok, true}","ref":"Ollama.API.html#create_blob/2-example"},{"type":"function","title":"Ollama.API.create_model/2","doc":"Creates a model using the given name and model file. Optionally\nstreamable.\n\nAny dependent blobs reference in the modelfile, such as `FROM` and `ADAPTER`\ninstructions, must exist first. See `check_blob/2` and `create_blob/2`.","ref":"Ollama.API.html#create_model/2"},{"type":"function","title":"Options - Ollama.API.create_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to create.\n* `:modelfile` (`t:String.t/0`) - Required. Contents of the Modelfile.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.API.html#create_model/2-options"},{"type":"function","title":"Example - Ollama.API.create_model/2","doc":"iex> modelfile = \"FROM llama2\\nSYSTEM \\\"You are mario from Super Mario Bros.\\\"\"\n    iex> Ollama.API.create_model(api, [\n    ...>   name: \"mario\",\n    ...>   modelfile: modelfile,\n    ...>   stream: true,\n    ...> ])\n    {:ok, Task{}}","ref":"Ollama.API.html#create_model/2-example"},{"type":"function","title":"Ollama.API.delete_model/2","doc":"Deletes a model and its data.","ref":"Ollama.API.html#delete_model/2"},{"type":"function","title":"Options - Ollama.API.delete_model/2","doc":"* `:source` (`t:String.t/0`) - Required. Name of the model to copy from.\n* `:destination` (`t:String.t/0`) - Required. Name of the model to copy to.","ref":"Ollama.API.html#delete_model/2-options"},{"type":"function","title":"Example - Ollama.API.delete_model/2","doc":"iex> Ollama.API.delete_model(api, name: \"llama2\")\n    {:ok, true}","ref":"Ollama.API.html#delete_model/2-example"},{"type":"function","title":"Ollama.API.embeddings/2","doc":"Generate embeddings from a model for the given prompt.","ref":"Ollama.API.html#embeddings/2"},{"type":"function","title":"Options - Ollama.API.embeddings/2","doc":"* `:model` (`t:String.t/0`) - Required. The name of the model used to generate the embeddings.\n* `:prompt` (`t:String.t/0`) - Required. The prompt used to generate the embedding.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.API.html#embeddings/2-options"},{"type":"function","title":"Example - Ollama.API.embeddings/2","doc":"iex> Ollama.API.embeddings(api, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Here is an article about llamas...\"\n    ...> ])\n    {:ok, %{\"embedding\" => [\n      0.5670403838157654, 0.009260174818336964, 0.23178744316101074, -0.2916173040866852, -0.8924556970596313,\n      0.8785552978515625, -0.34576427936553955, 0.5742510557174683, -0.04222835972905159, -0.137906014919281\n    ]}}","ref":"Ollama.API.html#embeddings/2-example"},{"type":"function","title":"Ollama.API.list_models/1","doc":"Lists all models that Ollama has available.","ref":"Ollama.API.html#list_models/1"},{"type":"function","title":"Example - Ollama.API.list_models/1","doc":"iex> Ollama.API.list_models(api)\n    {:ok, %{\"models\" => [\n      %{\"name\" => \"codellama:13b\", ...},\n      %{\"name\" => \"llama2:latest\", ...},\n    ]}}","ref":"Ollama.API.html#list_models/1-example"},{"type":"function","title":"Ollama.API.new/1","doc":"Creates a new API client with the provided URL. If no URL is given, it\ndefaults to `\"http://localhost:11434/api\"`.","ref":"Ollama.API.html#new/1"},{"type":"function","title":"Examples - Ollama.API.new/1","doc":"iex> api = Ollama.API.new(\"https://ollama.service.ai:11434\")\n    %Ollama.API{}","ref":"Ollama.API.html#new/1-examples"},{"type":"function","title":"Ollama.API.pull_model/2","doc":"Downloads a model from the ollama library. Optionally streamable.","ref":"Ollama.API.html#pull_model/2"},{"type":"function","title":"Options - Ollama.API.pull_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to pull.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.API.html#pull_model/2-options"},{"type":"function","title":"Example - Ollama.API.pull_model/2","doc":"iex> Ollama.API.pull_model(api, name: \"llama2\")\n    {:ok, %{\"status\" => \"success\"}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.API.pull_model(api, name: \"llama2\", stream: true)\n    {:ok, %Task{}}","ref":"Ollama.API.html#pull_model/2-example"},{"type":"function","title":"Ollama.API.push_model/2","doc":"Upload a model to a model library. Requires registering for\n[ollama.ai](https://ollama.ai) and adding a public key first. Optionally streamable.","ref":"Ollama.API.html#push_model/2"},{"type":"function","title":"Options - Ollama.API.push_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to pull.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.API.html#push_model/2-options"},{"type":"function","title":"Example - Ollama.API.push_model/2","doc":"iex> Ollama.API.push_model(api, name: \"mattw/pygmalion:latest\")\n    {:ok, %{\"status\" => \"success\"}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.API.push_model(api, name: \"mattw/pygmalion:latest\", stream: true)\n    {:ok, %Task{}}","ref":"Ollama.API.html#push_model/2-example"},{"type":"function","title":"Ollama.API.show_model/2","doc":"Shows all information for a specific model.","ref":"Ollama.API.html#show_model/2"},{"type":"function","title":"Options - Ollama.API.show_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to show.","ref":"Ollama.API.html#show_model/2-options"},{"type":"function","title":"Example - Ollama.API.show_model/2","doc":"iex> Ollama.API.show_model(api, name: \"llama2\")\n    {:ok, %{\n      \"details\" => %{\n        \"families\" => [\"llama\", \"clip\"],\n        \"family\" => \"llama\",\n        \"format\" => \"gguf\",\n        \"parameter_size\" => \"7B\",\n        \"quantization_level\" => \"Q4_0\"\n      },\n      \"modelfile\" => \"...\",\n      \"parameters\" => \"...\",\n      \"template\" => \"...\"\n    }}","ref":"Ollama.API.html#show_model/2-example"},{"type":"type","title":"Ollama.API.message/0","doc":"Chat message\n\nA chat message is a `t:map/0` with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `system`, `user` or `assistant`.\n* `:content` (`t:String.t/0`) - Required. The content of the message.\n* `:images` (list of `t:String.t/0`) - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.API.html#t:message/0"},{"type":"type","title":"Ollama.API.response/0","doc":"API function response","ref":"Ollama.API.html#t:response/0"},{"type":"type","title":"Ollama.API.t/0","doc":"Client struct","ref":"Ollama.API.html#t:t/0"},{"type":"module","title":"Ollama.Blob","doc":"Module for working for blobs in Ollama.\n\nCurrently this module only provides a function for generating a SHA256 digest\nof a binary blob.","ref":"Ollama.Blob.html"},{"type":"function","title":"Ollama.Blob.digest/1","doc":"Generates a SHA256 digest of a binary blob.","ref":"Ollama.Blob.html#digest/1"},{"type":"function","title":"Example - Ollama.Blob.digest/1","doc":"iex> Ollama.Blob.digest(\"hello\")\n    \"sha256:2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824\"","ref":"Ollama.Blob.html#digest/1-example"},{"type":"type","title":"Ollama.Blob.digest/0","doc":"Blob digest\n\nThe digest is a hex-encoded SHA256 hash of the binary blob, prefixed with the\nalgorithm.","ref":"Ollama.Blob.html#t:digest/0"},{"type":"type","title":"Example - Ollama.Blob.digest/0","doc":"\"sha256:054edec1d0211f624fed0cbca9d4f9400b0e491c43742af2c5b0abebf0c990d8\"","ref":"Ollama.Blob.html#t:digest/0-example"}],"content_type":"text/markdown"}